@@ -6,15 +6,15 @@ class Block:
 
 	progressions = Contemporary.reincarnatie
 	
-	bpm = 120
-	resolution = 8
+	bpm = 0
+	resolution = 0
 	meter = (4,4)
-	duration = 1
+	duration = 0
 
-	swing = True
-	key = 'C'
+	swing = 'Default'
+	key = 'Default'
 
-	wildness = 0.5
+	wildness = 0.0
 
 	def get_bpm(self, iterations, tick):
 		return self.bpm
