@@ -41,7 +41,7 @@ class Sequencer:
 		self.key = b.get_key(self.iterations)
 		self.progression = b.get_progression(self.iterations)
 		self.resolution = b.get_resolution(self.iterations)
-		self.instruments = b.get_instruments(self.iterations)
+		self.instruments = self.movement.get_instruments()
 		self.set_bpm(b.get_bpm(self.iterations, 0))
 		self.wild = b.get_wildness(self.iterations, 0)
 		self.reset_state()
